@@ -1,3 +1,9 @@
+from typing import Dict
+
+from vatis.asr_commons.config import Language
+from vatis.asr_commons.constants.custom_models import MODEL
+from vatis.asr_commons.custom_models import Model
+
 from vatis.live_asr.config_variables import API_KEY, AUTHENTICATION_PROVIDER_URL
 import requests
 from requests import Response
@@ -17,10 +23,20 @@ class ClientAuthorization:
         return self._service_host
 
 
-def get_auth_token() -> ClientAuthorization:
+def get_auth_token(model: Model = None, language: Language = None) -> ClientAuthorization:
+    assert model is not None or language is not None
+
+    query_params: Dict[str, str] = {'service': 'LIVE_ASR'}
+
+    if model is not None:
+        query_params[MODEL] = str(model.uid)
+
+    if language is not None:
+        query_params['language'] = language.value
+
     response: Response = requests.get(
         AUTHENTICATION_PROVIDER_URL,
-        params={'service': 'LIVE_ASR'},
+        params=query_params,
         headers={'Authorization': 'Bearer ' + API_KEY}
     )
 
